==> generalbrowser-0.0.1.tar.gz: generalbrowser-0.0.1/README.md <==
# generalbrowser
Missing description.

This package and 4 other make up [ManderaGeneral](https://github.com/Mandera).

## Information
| Package                                                            | Ver                                               | Latest Release       | Python                                                                                                                   | Platform        |   Lvl | Todo                                                       | Tests   |
|:-------------------------------------------------------------------|:--------------------------------------------------|:---------------------|:-------------------------------------------------------------------------------------------------------------------------|:----------------|------:|:-----------------------------------------------------------|:--------|
| [generalbrowser](https://github.com/ManderaGeneral/generalbrowser) | [0.0.1](https://pypi.org/project/generalbrowser/) | 2021-11-10 17:43 CET | [3.8](https://www.python.org/downloads/release/python-380/), [3.9](https://www.python.org/downloads/release/python-390/) | Windows, Ubuntu |     1 | [1](https://github.com/ManderaGeneral/generalbrowser#Todo) | 100 %   |

## Contents
<pre>
<a href='#generalbrowser'>generalbrowser</a>
├─ <a href='#Information'>Information</a>
├─ <a href='#Contents'>Contents</a>
├─ <a href='#Installation'>Installation</a>
├─ <a href='#Attributes'>Attributes</a>
└─ <a href='#Todo'>Todo</a>
</pre>

## Installation
| Command                      | <a href='https://pypi.org/project/generallibrary'>generallibrary</a>   |
|:-----------------------------|:-----------------------------------------------------------------------|
| `pip install generalbrowser` | Yes                                                                    |

## Attributes
<pre>
<a href='https://github.com/ManderaGeneral/generalbrowser/blob/master/generalbrowser/__init__.py#L1'>Module: generalbrowser</a> <b>(Untested)</b>
</pre>

## Todo
| Module                                                                                                               | Message                                                                                                                                        |
|:---------------------------------------------------------------------------------------------------------------------|:-----------------------------------------------------------------------------------------------------------------------------------------------|
| <a href='https://github.com/ManderaGeneral/generalbrowser/blob/master/generalbrowser/__init__.py#L1'>__init__.py</a> | <a href='https://github.com/ManderaGeneral/generalbrowser/blob/master/generalbrowser/__init__.py#L1'>[UnitTest] for Module: generalbrowser</a> |

<sup>
Generated 2021-11-10 17:43 CET for commit <a href='https://github.com/ManderaGeneral/generalbrowser/commit/master'>master</a>.
</sup>

==> generalbrowser-0.0.2.tar.gz: generalbrowser-0.0.2/README.md <==
# generalbrowser
Missing description.

This package and 5 other make up [ManderaGeneral](https://github.com/ManderaGeneral).

## Information
| Package                                                            | Ver                                               | Latest Release       | Python                                                                                                                   | Platform        |   Lvl | Todo                                                       | Tests   |
|:-------------------------------------------------------------------|:--------------------------------------------------|:---------------------|:-------------------------------------------------------------------------------------------------------------------------|:----------------|------:|:-----------------------------------------------------------|:--------|
| [generalbrowser](https://github.com/ManderaGeneral/generalbrowser) | [0.0.2](https://pypi.org/project/generalbrowser/) | 2021-11-19 00:34 CET | [3.8](https://www.python.org/downloads/release/python-380/), [3.9](https://www.python.org/downloads/release/python-390/) | Windows, Ubuntu |     1 | [1](https://github.com/ManderaGeneral/generalbrowser#Todo) | 100 %   |

## Contents
<pre>
<a href='#generalbrowser'>generalbrowser</a>
├─ <a href='#Information'>Information</a>
├─ <a href='#Contents'>Contents</a>
├─ <a href='#Installation'>Installation</a>
├─ <a href='#Attributes'>Attributes</a>
└─ <a href='#Todo'>Todo</a>
</pre>

## Installation
| Command                      | <a href='https://pypi.org/project/generallibrary'>generallibrary</a>   |
|:-----------------------------|:-----------------------------------------------------------------------|
| `pip install generalbrowser` | Yes                                                                    |

## Attributes
<pre>
<a href='https://github.com/ManderaGeneral/generalbrowser/blob/52605ce/generalbrowser/__init__.py#L1'>Module: generalbrowser</a> <b>(Untested)</b>
</pre>

## Todo
| Module                                                                                                               | Message                                                                                                                                        |
|:---------------------------------------------------------------------------------------------------------------------|:-----------------------------------------------------------------------------------------------------------------------------------------------|
| <a href='https://github.com/ManderaGeneral/generalbrowser/blob/master/generalbrowser/__init__.py#L1'>__init__.py</a> | <a href='https://github.com/ManderaGeneral/generalbrowser/blob/master/generalbrowser/__init__.py#L1'>[UnitTest] for Module: generalbrowser</a> |

<sup>
Generated 2021-11-19 00:34 CET for commit <a href='https://github.com/ManderaGeneral/generalbrowser/commit/52605ce'>52605ce</a>.
</sup>
